//*****************************************************************************
//*****************************************************************************
//  FILENAME:   parameters.h
//  Version: 1.0, 2007/03/06
//  Generated by Andy Kiser
//
//  DESCRIPTION:  Handling of Volatile / Nonvolatile parameters
//
//	This library allows for the following maximum number of parameters
//		  8 Bit	: x16
//		 16 Bit	: x16
//		 32 Bit : x4
//		168 Bit : x9	(Strings, 20+1 characters)
//-----------------------------------------------------------------------------
// Originally authored by Toradex AG. This work is now available under the terms and conditions
// of the Creative Commons License 'Attribution CC BY', details of which can be found here:
// http://creativecommons.org/licenses/by/3.0/
//*****************************************************************************
//*****************************************************************************
#ifndef __PARAMETERS_H__
#define	__PARAMETERS_H__

#include <m8c.h>

// maximum allowed number of parameters
// --> see also #define NUM_PARAM_8 ... 
#define MAX_PARAM_8		16
#define MAX_PARAM_16	16
#define MAX_PARAM_32	4
#define MAX_PARAM_168	9

// parameter to define if volatile / nonvolatile parameter should be accessed
#define NONVOLATILE		TRUE
#define VOLATILE		FALSE


// type definitions
typedef	char tParam_168 [21];	// Param168 is a string holding max. 20+1 chars.


// function prototypes
//-----------------------------------------------------------------------------
// Initializing "Parameters.c"
// e.g. copy all Parameters from Flash into RAM
//-----------------------------------------------------------------------------
extern void Parameters_Start(void);

//-----------------------------------------------------------------------------
//	Setting Parameters
//  The parameter "Temperature" can be ignored, if "NonVolatile" is FALSE
//-----------------------------------------------------------------------------
extern void Set_Param_8   (BYTE index, BOOL NonVolatile, BYTE       value);
extern void Set_Param_16  (BYTE index, BOOL NonVolatile, WORD       value);
extern void Set_Param_32  (BYTE index, BOOL NonVolatile, DWORD      value);
extern void Set_Param_168 (BYTE index, BOOL NonVolatile, tParam_168 value);

//-----------------------------------------------------------------------------
//	Reading Parameters
//-----------------------------------------------------------------------------
extern void Get_Param_8   (BYTE index, BOOL NonVolatile, BYTE       *value);
extern void Get_Param_16  (BYTE index, BOOL NonVolatile, WORD       *value);
extern void Get_Param_32  (BYTE index, BOOL NonVolatile, DWORD      *value);
extern void Get_Param_168 (BYTE index, BOOL NonVolatile, tParam_168  value);


#endif