//*****************************************************************************
//*****************************************************************************
//  FILENAME:   sensor.h
//  Version: 1.0, 2007/03/08 
//  Generated by Andy Kiser
//
//  DESCRIPTION:  Sensor specific functions and declarations
//
//-----------------------------------------------------------------------------
// Originally authored by Toradex AG. This work is now available under the terms and conditions
// of the Creative Commons License 'Attribution CC BY', details of which can be found here:
// http://creativecommons.org/licenses/by/3.0/
//*****************************************************************************
//*****************************************************************************
#include <m8c.h>
#include "parameters.h"

//-----------------------------------------------------------------------------
// Sensor parameters
// the first parameters (lowest indices) are identical for each sensor
// additional parameters may be defined here 
//-----------------------------------------------------------------------------
// actual used number of parameters
// --> see also #define MAX_PARAM_8 ... in parameters.h
#define NUM_PARAM_8		8
#define NUM_PARAM_16	7
#define NUM_PARAM_32	1
#define NUM_PARAM_168	7

// Assignment of Parameters
#define PAR8_REPORTMODE	0
#define PAR8_LEDMODE 1
#define PAR8_SENSITIVITY 2
#define PAR8_SHIELD 3			//Not documented
#define PAR8_FINGER_THRESHOLD 4
#define PAR8_RESOLUTION 5		//Only 12 and 16 in Documentation
#define PAR8_SCAN_SPEED 6		//Not Documented
#define PAR8_AUTO_BASE_LINE 7
//#define PAR8_DEBOUNCE 8		//Needs Hack in Assembler
//#define PAR8_HYSTERESIS 9		//Needs Hack in Assembler

#define PAR16_REPORTRATE_MS	0
#define PAR16_SAMPLERATE_MS	1
#define PAR16_SAMPLERATE_US	2
#define PAR16_SET_BASELINE_0 3	//Only Usefull if the Auto Base Line is switched off
#define PAR16_SET_BASELINE_1 4	//Only Usefull if the Auto Base Line is switched off
#define PAR16_SET_BASELINE_2 5	//Only Usefull if the Auto Base Line is switched off
#define PAR16_SET_BASELINE_3 6	//Only Usefull if the Auto Base Line is switched off

#define PAR32_DUMMY			0

#define PAR168_USRDEVNAME	0
#define PAR168_USRCHNAME_0	1
#define PAR168_USRCHNAME_1	2
#define PAR168_USRCHNAME_2	3
#define PAR168_USRCHNAME_3	4
#define PAR168_USRCHNAME_4	5
#define PAR168_USRCHNAME_5	6

// factory defaults are defined in the source file of the sensor
extern	const BYTE			FactoryDefault_Param_8   [NUM_PARAM_8];
extern	const WORD			FactoryDefault_Param_16  [NUM_PARAM_16];
extern	const DWORD			FactoryDefault_Param_32  [NUM_PARAM_32];
extern	const tParam_168	FactoryDefault_Param_168 [NUM_PARAM_168];

//-----------------------------------------------------------------------------
// Type Definitions
//-----------------------------------------------------------------------------
typedef struct
{
	BYTE Ch0_LSB;
	BYTE Ch0_MSB;
	BYTE CH1;
	BYTE CH2_LSB;
	BYTE CH2_MSB;
	BYTE CH3_LSB;
	BYTE CH3_MSB;
	BYTE CH4_LSB;
	BYTE CH4_MSB;
	BYTE CH5_LSB;
	BYTE CH5_MSB;
} tReport;

//-----------------------------------------------------------------------------
// Global Variables
//-----------------------------------------------------------------------------
extern tReport Report;
#define IN_REPORT_SIZE (sizeof(tReport))

extern BOOL	NewSample;

//-----------------------------------------------------------------------------
// Initializes the MS5534 
//-----------------------------------------------------------------------------
extern void Sensor_Start (void);

//-----------------------------------------------------------------------------
// Prepare Measurement for Suspend
//-----------------------------------------------------------------------------
extern void Sensor_Suspend(void);

//-----------------------------------------------------------------------------
// Send Sequence to Start Temperature Measurement
//-----------------------------------------------------------------------------
extern void Sensor_Resume(void);

//-----------------------------------------------------------------------------
// void Sensor_FSM_Measure(void)
//
//	finite state machine to control the measurement process for 
//  the SCA100T sensor
//
//  IMPORTANT: 	call this routine once every millisecond. Otherwise the timing
//				parameters cannot be met.
//-----------------------------------------------------------------------------
extern void Sensor_FSM_Measure(void);

//-----------------------------------------------------------------------------
// Function that will be called when a FEATURE REPORT is received that 
// cannot be handled with the standard functionality in feature.c
// The feature report data is available in the "FEATURE_RPT" variable
//
// --> see feature.c for an example how to parse FEATURE_RPT
//
//	return Value: number of Parameter bytes (1-31) that are 
//				  returned in the IN report
//-----------------------------------------------------------------------------
extern BYTE Sensor_Specific_Feature(void);

//-----------------------------------------------------------------------------
// Function that will be called when a FEATURE REPORT is received that 
// sets / gets a 8/16/32/168bit parameter in feature.c
// The feature report data is available in the "FEATURE_RPT" variable
//
// --> see feature.c for an example how to parse FEATURE_RPT
//-----------------------------------------------------------------------------
extern void Sensor_Specific_Parameter(BYTE *NumberOfReturnedBytes);

//-----------------------------------------------------------------------------
// debug function
//-----------------------------------------------------------------------------
extern void Sensor_Debug(void);

// end of file sensor.h
